pyMagnum
========

pyMagnum is a Python 3 implementation of a read only interface to the
Magnum Energy network.

`The Python package site <https://pypi.org/project/pymagnum/>`_

This software is not endorsed or supported by Magnum Energy, a product
of Sensata Technologies https://www.magnum-dimensions.com/

Please read the documentation before installing this package.
Some operating systems, including Raspberry Pi OS,
require you to use ``python3`` and ``pip3`` to use the Python 3 version of these tools.

`Documentation <https://pymagnum.readthedocs.io/>`_

`Changes <https://github.com/CharlesGodwin/pymagnum/blob/master/CHANGES.rst>`_

Copyright (c) 2018-2020 Charles Godwin magnum@godwin.ca

SPDX-License-Identifier: BSD-3-Clause
